@@ -4,7 +4,7 @@
  by the TrueCrypt License 3.0.
 
  Modifications and additions to the original source code (contained in this file)
- and all other portions of this file are Copyright (c) 2013-2017 IDRIX
+ and all other portions of this file are Copyright (c) 2013-2025 AM Crypto
  and are governed by the Apache License 2.0 the full text of which is
  contained in the file License.txt included in VeraCrypt binary and source
  code distribution packages.
@@ -23,6 +23,9 @@ namespace VeraCrypt
 		ApplicationExecutablePath = sr.DeserializeWString ("ApplicationExecutablePath");
 		sr.Deserialize ("ElevateUserPrivileges", ElevateUserPrivileges);
 		sr.Deserialize ("FastElevation", FastElevation);
+		sr.Deserialize ("UserEnvPATH", UserEnvPATH);
+		sr.Deserialize ("UseDummySudoPassword", UseDummySudoPassword);
+		sr.Deserialize ("AllowInsecureMount", AllowInsecureMount);
 	}
 
 	void CoreServiceRequest::Serialize (shared_ptr <Stream> stream) const
@@ -33,6 +36,9 @@ namespace VeraCrypt
 		sr.Serialize ("ApplicationExecutablePath", wstring (ApplicationExecutablePath));
 		sr.Serialize ("ElevateUserPrivileges", ElevateUserPrivileges);
 		sr.Serialize ("FastElevation", FastElevation);
+		sr.Serialize ("UserEnvPATH", UserEnvPATH);
+		sr.Serialize ("UseDummySudoPassword", UseDummySudoPassword);
+		sr.Serialize ("AllowInsecureMount", AllowInsecureMount);
 	}
 
 	// CheckFilesystemRequest
