@@ -23,6 +23,7 @@ namespace VeraCrypt
 	VolumePimWizardPage::VolumePimWizardPage (wxPanel* parent)
 		: VolumePimWizardPageBase (parent)
 	{
+		VolumePimTextCtrl->SetMinSize (wxSize (Gui->GetCharWidth (VolumePimTextCtrl) * 15, -1));
 		SetPimValidator ();
 	}
 
@@ -91,9 +92,7 @@ namespace VeraCrypt
 
 	void VolumePimWizardPage::SetPimValidator ()
 	{
-		wxTextValidator validator (wxFILTER_INCLUDE_CHAR_LIST);  // wxFILTER_NUMERIC does not exclude - . , etc.
-		const wxChar *valArr[] = { L"0", L"1", L"2", L"3", L"4", L"5", L"6", L"7", L"8", L"9" };
-		validator.SetIncludes (wxArrayString (array_capacity (valArr), (const wxChar **) &valArr));
+		wxTextValidator validator (wxFILTER_DIGITS);
 		VolumePimTextCtrl->SetValidator (validator);
 	}
 
