@@ -3,8 +3,8 @@
  Copyright (c) 2008-2012 TrueCrypt Developers Association and which is governed
  by the TrueCrypt License 3.0.
 
- Modifications and additions to the original source code (contained in this file) 
- and all other portions of this file are Copyright (c) 2013-2016 IDRIX
+ Modifications and additions to the original source code (contained in this file)
+ and all other portions of this file are Copyright (c) 2013-2025 AM Crypto
  and are governed by the Apache License 2.0 the full text of which is
  contained in the file License.txt included in VeraCrypt binary and source
  code distribution packages.
@@ -28,10 +28,12 @@ namespace VeraCrypt
 
 		bool Exists (const string &key) const { return Map.find (key) != Map.end(); }
 		wstring Get (const string &key) const;
+		string GetPreferredLang () const { return PreferredLang; }
 		void Init ();
 
 	protected:
 		map <string, wstring> Map;
+		string PreferredLang;
 
 	private:
 		LanguageStrings (const LanguageStrings &);
