@@ -4,7 +4,7 @@
  by the TrueCrypt License 3.0.
 
  Modifications and additions to the original source code (contained in this file)
- and all other portions of this file are Copyright (c) 2013-2017 IDRIX
+ and all other portions of this file are Copyright (c) 2013-2025 AM Crypto
  and are governed by the Apache License 2.0 the full text of which is
  contained in the file License.txt included in VeraCrypt binary and source
  code distribution packages.
@@ -237,6 +237,10 @@ namespace VeraCrypt
 			}
 			return 1;
 
+		case WM_DESTROY:
+			DetachProtectionFromCurrentThread();
+			break;
+
 		case WM_COMMAND:
 
 			switch (lw)
@@ -452,13 +456,13 @@ namespace VeraCrypt
 		case WM_CTLCOLORSTATIC:
 			{
 				HDC hdc = (HDC)	wParam;
-				HWND hw = (HWND) lParam;
-				if (hw == GetDlgItem(hwndDlg, IDC_FAVORITE_VOLUME_ID))
+				HWND hwnd = (HWND) lParam;
+				if (hwnd == GetDlgItem(hwndDlg, IDC_FAVORITE_VOLUME_ID))
 				{
 					// This the favorite ID field. Make its background like normal edit
 					HBRUSH hbr = GetSysColorBrush (COLOR_WINDOW);
 					::SelectObject(hdc, hbr);
-					return (BOOL) hbr;
+					return (BOOL)(INT_PTR)hbr;
 				}
 			}
 			break;
@@ -731,7 +735,7 @@ namespace VeraCrypt
 
 		FavoritesOnArrivalMountRequired.clear();
 
-		foreach (const FavoriteVolume favorite, FavoriteVolumes)
+		for (const FavoriteVolume favorite: FavoriteVolumes)
 		{
 			if (favorite.MountOnArrival)
 			{
@@ -741,7 +745,7 @@ namespace VeraCrypt
 				{
 					bool present = false;
 
-					foreach (const FavoriteVolume favoriteConnected, FavoritesMountedOnArrivalStillConnected)
+					for (const FavoriteVolume favoriteConnected: FavoritesMountedOnArrivalStillConnected)
 					{
 						if (favorite.Path == favoriteConnected.Path)
 						{
