@@ -4,7 +4,7 @@
 # by the TrueCrypt License 3.0.
 #
 # Modifications and additions to the original source code (contained in this file)
-# and all other portions of this file are Copyright (c) 2013-2017 IDRIX
+# and all other portions of this file are Copyright (c) 2013-2025 AM Crypto
 # and are governed by the Apache License 2.0 the full text of which is
 # contained in the file License.txt included in VeraCrypt binary and source
 # code distribution packages.
@@ -52,7 +52,7 @@ then
 
 	if [ $XMESSAGE -eq 0 ] || ([ $XTERM -eq 0 ] && [ $GTERM -eq 0 ] && [ $KTERM -eq 0 ])
 	then
-		which gnome-terminal && exec gnome-terminal -e "$0"
+		which gnome-terminal && exec gnome-terminal -- "$0"
 		which konsole && exec konsole -e "$0"
 		which xterm && exec xterm -e "$0"
 
@@ -77,7 +77,7 @@ show_message()
 	then
 		if [ $XMESSAGE -eq 1 ]
 		then
-			xmessage -center -buttons OK -default OK "$*"
+			xmessage -title "VeraCrypt Setup" -center -buttons OK -default OK "$*"
 		else
 			if [ $TTY -eq 1 ]
 			then
@@ -89,11 +89,11 @@ show_message()
 				else
 					if [ $GTERM -eq 1 ]
 					then
-						gnome-terminal --title='VeraCrypt Setup' -e "sh -c \"echo $*; read A\""
+						gnome-terminal --title='VeraCrypt Setup' -- sh -c "echo $*; read A"
 					else
 						if [ $KTERM -eq 1 ]
 						then
-							konsole --qwindowtitle 'VeraCrypt Setup' --caption 'VeraCrypt Setup' -e sh -c "echo $*; read A"
+							konsole --qwindowtitle 'VeraCrypt Setup' -e sh -c "echo $*; read A"
 						fi
 					fi
 				fi
@@ -136,7 +136,7 @@ the TrueCrypt License version 3.0, a verbatim copy of both
 licenses can be found below.
 
 This license does not grant you rights to use any
-contributors' name, logo, or trademarks, including IDRIX,
+contributors' name, logo, or trademarks, including AM Crypto,
 VeraCrypt and all derivative names.
 For example, the following names are not allowed: VeraCrypt,
 VeraCrypt+, VeraCrypt Professional, iVeraCrypt, etc. Nor any
@@ -845,11 +845,11 @@ INSTALL=-1
 if [ $XMESSAGE -eq 1 ]
 then
 
-	cat <<_END | xmessage -center -file - -buttons "Exit:1,Extract .$PACKAGE_TYPE Package File:20,Install VeraCrypt:10" -default 'Install VeraCrypt'
+	cat <<_END | xmessage -title "VeraCrypt Setup" -center -file - -buttons "Exit:1,Extract .$PACKAGE_TYPE Package File:20,Install VeraCrypt:10" -default 'Install VeraCrypt'
 VeraCrypt $VERSION Setup
 ====================
- VeraCrypt is a free disk encryption software brought to you by IDRIX
- (http://www.idrix.fr) and that is based on TrueCrypt.
+ VeraCrypt is a free disk encryption software brought to you by AM Crypto
+ (https://amcrypto.jp) and that is based on TrueCrypt.
  It is a software system for establishing and maintaining an
  on-the-fly-encrypted volume (data storage device). On-the-fly encryption
  means that data are automatically encrypted or decrypted right before they
@@ -934,7 +934,7 @@ then
 
 # GUI license agreement
 
-	cat <<_END | cat - $LICENSE | xmessage -center -file - -buttons 'I accept and agree to be bound by the license terms:10,I do not accept:20'
+	cat <<_END | cat - $LICENSE | xmessage -title "VeraCrypt Setup" -center -file - -buttons 'I accept and agree to be bound by the license terms:10,I do not accept:20'
 
 Before you can use, extract, or install VeraCrypt, you must accept these
 license terms.
@@ -1038,7 +1038,7 @@ Requirements for Running VeraCrypt:
 -----------------------------------
 
  - FUSE library and tools
- - device mapper tool
+ - device mapper tools
  - PC/SC Lite (optional)
 
 _INFO
@@ -1066,21 +1066,21 @@ then
 	then
 		if [ $XTERM -eq 1 ]
 		then
-			exec xterm -T 'VeraCrypt Setup' -e sh -c "echo Installing package...; $SUDO $PACKAGE_INSTALLER $PACKAGE_INSTALLER_OPTS $PACKAGE; rm -f $PACKAGE; echo; echo Press Enter to exit...; read A"
+			exec xterm -T 'VeraCrypt Setup' -e sh -c "echo Installing package...; $SUDO $PACKAGE_INSTALLER $PACKAGE_INSTALLER_OPTS $PACKAGE; rm -f $PACKAGE; $SUDO update-mime-database /usr/share/mime >/dev/null 2>&1; $SUDO update-desktop-database -q; echo; echo Press Enter to exit...; read A"
 		else
 			if [ $GTERM -eq 1 ]
 			then
-				exec gnome-terminal --title='VeraCrypt Setup' -e "sh -c \"echo Installing package...; $SUDO $PACKAGE_INSTALLER $PACKAGE_INSTALLER_OPTS $PACKAGE; rm -f $PACKAGE; echo; echo Press Enter to exit...; read A\""
+				exec gnome-terminal --title='VeraCrypt Setup' -- sh -c "echo Installing package...; $SUDO $PACKAGE_INSTALLER $PACKAGE_INSTALLER_OPTS $PACKAGE; rm -f $PACKAGE; $SUDO update-mime-database /usr/share/mime >/dev/null 2>&1; $SUDO update-desktop-database -q; echo; echo Press Enter to exit...; read A"
 			else
 				if [ $KTERM -eq 1 ]
 				then
-					exec konsole --qwindowtitle 'VeraCrypt Setup' --caption 'VeraCrypt Setup' -e sh -c "echo Installing package...; $SUDO $PACKAGE_INSTALLER $PACKAGE_INSTALLER_OPTS $PACKAGE; rm -f $PACKAGE; echo; echo Press Enter to exit...; read A"
+					exec konsole --qwindowtitle 'VeraCrypt Setup' -e sh -c "echo Installing package...; $SUDO $PACKAGE_INSTALLER $PACKAGE_INSTALLER_OPTS $PACKAGE; rm -f $PACKAGE; $SUDO update-mime-database /usr/share/mime >/dev/null 2>&1; $SUDO update-desktop-database -q; echo; echo Press Enter to exit...; read A"
 				fi
 			fi
 		fi
 	else
 		echo 'Installing package...'
-		$SUDO $PACKAGE_INSTALLER $PACKAGE_INSTALLER_OPTS $PACKAGE && INSTALLED=1
+		$SUDO $PACKAGE_INSTALLER $PACKAGE_INSTALLER_OPTS $PACKAGE && INSTALLED=1 && $SUDO update-mime-database /usr/share/mime >/dev/null 2>&1 && $SUDO update-desktop-database -q
 
 		if [ $INSTALLED -eq 1 ]
 		then
