@@ -4,7 +4,7 @@
  by the TrueCrypt License 3.0.
 
  Modifications and additions to the original source code (contained in this file)
- and all other portions of this file are Copyright (c) 2013-2017 IDRIX
+ and all other portions of this file are Copyright (c) 2013-2025 AM Crypto
  and are governed by the Apache License 2.0 the full text of which is
  contained in the file License.txt included in VeraCrypt binary and source
  code distribution packages.
@@ -47,6 +47,7 @@ namespace VeraCrypt
 	struct CipherTestVector
 	{
 		uint8 Key[32];
+		size_t KeyLength;
 		uint8 Plaintext[16];
 		uint8 Ciphertext[16];
 	};
@@ -58,6 +59,7 @@ namespace VeraCrypt
 				0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
 				0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f,
 			},
+			32,
 			{
 				0x00, 0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77, 0x88, 0x99, 0xaa, 0xbb, 0xcc, 0xdd, 0xee, 0xff
 			},
@@ -75,6 +77,7 @@ namespace VeraCrypt
 				0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
 				0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f
 			},
+			32,
 			{
 				0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f
 			},
@@ -91,6 +94,7 @@ namespace VeraCrypt
 				0xD4, 0x3B, 0xB7, 0x55, 0x6E, 0xA3, 0x2E, 0x46, 0xF2, 0xA2, 0x82, 0xB7, 0xD4, 0x5B, 0x4E, 0x0D,
 				0x57, 0xFF, 0x73, 0x9D, 0x4D, 0xC9, 0x2C, 0x1B, 0xD7, 0xFC, 0x01, 0x70, 0x0C, 0xC8, 0x21, 0x6F
 			},
+			32,
 			{
 				0x90, 0xAF, 0xE9, 0x1B, 0xB2, 0x88, 0x54, 0x4F, 0x2C, 0x32, 0xDC, 0x23, 0x9B, 0x26, 0x35, 0xE6
 			},
@@ -107,6 +111,7 @@ namespace VeraCrypt
 				0x01, 0x23, 0x45, 0x67, 0x89, 0xAB, 0xCD, 0xEF, 0xFE, 0xDC, 0xBA, 0x98, 0x76, 0x54, 0x32, 0x10, 
 				0x00, 0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77,	0x88, 0x99, 0xAA, 0xBB, 0xCC, 0xDD, 0xEE, 0xFF
 			},
+			32,
 			{
 				0x01, 0x23, 0x45, 0x67,	0x89, 0xAB, 0xCD, 0xEF, 0xFE, 0xDC, 0xBA, 0x98, 0x76, 0x54, 0x32, 0x10
 			},
@@ -119,6 +124,7 @@ namespace VeraCrypt
 				0x2B, 0xD6, 0x45, 0x9F, 0x82, 0xC5, 0xB3, 0x00, 0x95, 0x2C, 0x49, 0x10, 0x48, 0x81, 0xFF, 0x48, 
 				0x2B, 0xD6, 0x45, 0x9F, 0x82, 0xC5, 0xB3, 0x00,	0x95, 0x2C, 0x49, 0x10, 0x48, 0x81, 0xFF, 0x48
 			},
+			32,
 			{
 				0xE6, 0x84, 0x42, 0x17,	0x16, 0xFC, 0x0B, 0x01, 0xAE, 0xB5, 0xC6, 0x76, 0x51, 0x20, 0xF9, 0x5F
 			},
@@ -135,6 +141,7 @@ namespace VeraCrypt
 				0x88, 0x99, 0xAA, 0xBB, 0xCC, 0xDD, 0xEE, 0xFF, 0x00, 0x11, 0x22, 0x33,	0x44, 0x55, 0x66, 0x77, 
 				0xFE, 0xDC, 0xBA, 0x98, 0x76, 0x54, 0x32, 0x10,	0x01, 0x23, 0x45, 0x67, 0x89, 0xAB, 0xCD, 0xEF
 			},
+			32,
 			{
 				0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77, 0x00, 0xFF, 0xEE, 0xDD, 0xCC,	0xBB, 0xAA, 0x99, 0x88
 			},
@@ -147,6 +154,7 @@ namespace VeraCrypt
 				0x88, 0x99, 0xAA, 0xBB, 0xCC, 0xDD, 0xEE, 0xFF, 0x00, 0x11, 0x22, 0x33,	0x44, 0x55, 0x66, 0x77, 
 				0xFE, 0xDC, 0xBA, 0x98, 0x76, 0x54, 0x32, 0x10,	0x01, 0x23, 0x45, 0x67, 0x89, 0xAB, 0xCD, 0xEF
 			},
+			32,
 			{
 				0x00, 0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77, 0x88, 0x99, 0xAA, 0xBB,	0xCC, 0xEE, 0xFF, 0x0A
 			},
@@ -162,7 +170,7 @@ namespace VeraCrypt
 		Buffer buffer (cipher.GetBlockSize());
 		for (size_t i = 0; i < testVectorCount; ++i)
 		{
-			cipher.SetKey (ConstBufferPtr (testVector[i].Key, sizeof (testVector[i].Key)));
+			cipher.SetKey (ConstBufferPtr (testVector[i].Key, testVector[i].KeyLength));
 			buffer.CopyFrom (ConstBufferPtr (testVector[i].Plaintext, sizeof (testVector[i].Plaintext)));
 			cipher.EncryptBlock (buffer);
 
@@ -522,7 +530,8 @@ namespace VeraCrypt
 				Buffer modeKey (ea.GetKeySize());
 				for (size_t mi = 0; mi < modeKey.Size(); mi++)
 					modeKey[mi] = (uint8) mi;
-				modeKey.CopyFrom (ConstBufferPtr (XtsTestVectors[array_capacity (XtsTestVectors)-1].key2, sizeof (XtsTestVectors[array_capacity (XtsTestVectors)-1].key2)));
+				size_t copySize = VC_MIN(modeKey.Size(), sizeof (XtsTestVectors[array_capacity (XtsTestVectors)-1].key2));
+				modeKey.CopyFrom (ConstBufferPtr (XtsTestVectors[array_capacity (XtsTestVectors)-1].key2, copySize));
 
 				mode->SetKey (modeKey);
 				ea.SetMode (mode);
@@ -977,7 +986,8 @@ namespace VeraCrypt
 			Buffer modeKey (ea.GetKeySize());
 			for (size_t mi = 0; mi < modeKey.Size(); mi++)
 				modeKey[mi] = (uint8) mi;
-			modeKey.CopyFrom (ConstBufferPtr (XtsTestVectors[array_capacity (XtsTestVectors)-1].key2, sizeof (XtsTestVectors[array_capacity (XtsTestVectors)-1].key2)));
+			size_t copySize = VC_MIN(modeKey.Size(), sizeof (XtsTestVectors[array_capacity (XtsTestVectors)-1].key2));
+			modeKey.CopyFrom (ConstBufferPtr (XtsTestVectors[array_capacity (XtsTestVectors)-1].key2, copySize));
 
 			mode->SetKey (modeKey);
 			ea.SetMode (mode);
